// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <StepAP214_AppliedPresentedItem.hxx>
#include <StepAP214_PresentedItemSelect.hxx>

IMPLEMENT_STANDARD_RTTIEXT(StepAP214_AppliedPresentedItem, StepVisual_PresentedItem)

StepAP214_AppliedPresentedItem::StepAP214_AppliedPresentedItem() {}

void StepAP214_AppliedPresentedItem::Init(
  const Handle(StepAP214_HArray1OfPresentedItemSelect)& aItems)
{
  // --- classe own fields ---
  items = aItems;
}

void StepAP214_AppliedPresentedItem::SetItems(
  const Handle(StepAP214_HArray1OfPresentedItemSelect)& aItems)
{
  items = aItems;
}

Handle(StepAP214_HArray1OfPresentedItemSelect) StepAP214_AppliedPresentedItem::Items() const
{
  return items;
}

StepAP214_PresentedItemSelect StepAP214_AppliedPresentedItem::ItemsValue(
  const Standard_Integer num) const
{
  return items->Value(num);
}

Standard_Integer StepAP214_AppliedPresentedItem::NbItems() const
{
  if (items.IsNull())
    return 0;
  return items->Length();
}
